==> tasks-v1.8.8.zip: tasks/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Tildelte brukere</strong> kan utføre denne oppgaven',
    '<strong>Create</strong> task list' => '<strong>Lag</strong> liste av oppgaver',
    '<strong>Edit</strong> task' => '<strong>Rediger</strong> oppgave',
    '<strong>Edit</strong> task list' => '<strong>Rediger</strong> listen med oppgaver',
    '<strong>Your</strong> tasks' => '<strong>Dine</strong> oppgaver',
    'Accept Task' => 'Godta oppgave',
    'Add task' => 'Legg til oppgave',
    'All Day' => 'Hele dagen',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Tillater brukeren å opprette nye oppgaver, brukeren vil kun kunne redigere og slette egne oppgaver',
    'Already requested' => 'Allerede forespurt',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Enhver bruker med en tillatelse til "Behandle ufordelte oppgaver" kan jobbe med denne oppgaven',
    'Anyone can work on this task!' => 'Hvem som helst kan jobbe med denne oppgaven.',
    'Assign users' => 'Tilknytt brukere',
    'Assigned' => 'Tildelt',
    'Assignments:' => 'Oppdrag:',
    'Begin Task' => 'Start oppgaven',
    'Checklist:' => 'Sjekliste:',
    'Close' => 'Lukk',
    'Color' => 'Farge',
    'Completed' => 'Ferdig',
    'Continue Review' => 'Fortsett gjennomgangen',
    'Create tasks' => 'Lag oppgaver',
    'Created by me' => 'Opprettet av meg',
    'Date' => 'Dato',
    'Deadline at' => 'Frist til',
    'Delete' => 'Slett',
    'Delete list' => 'Slett liste',
    'Description' => 'Beskrivelse',
    'Do you really want to delete this task?' => 'Ønsker du virkelig og slette denne oppgaven?',
    'Drag entry' => 'Dra element',
    'Edit' => 'Rediger',
    'Edit list' => 'Rediger liste',
    'End' => 'Slutt',
    'End Date' => 'Slutter dato',
    'End Time' => 'Slutt',
    'End time must be after start time!' => 'Aktiviteten kan ikke slutte før den har startet!',
    'Filter' => 'Filter',
    'Finish Task' => 'Avsluttede oppgaver',
    'General' => 'Generelt',
    'General Settings' => 'Generelle innstillinger ',
    'Hide this list once all tasks are completed' => 'Skjul listen når alle oppgavene er ferdige',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Hvis ingen tilordnet bruker er valgt, kan hvert gruppemedlem med tillatelse til å behandle ufordelte oppgaver, behandle oppgaven.',
    'In Progress' => 'I arbeid',
    'In Review' => 'Under gjennomgang',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Hvis vurderingsalternativet er aktivt, må en <strong>ansvarlig</strong> bruker vurdere og avvise eller bekrefte denne oppgaven før ferdigstillelse.',
    'Invalid task list selection.' => 'Ugyldig valg av oppgave liste',
    'Let Task Review' => 'La oppgave gjennomgang',
    'No Scheduling set for this Task' => 'Ingen planlegging satt til denne oppgaven',
    'No pending tasks found' => 'Ingen ventende oppgaver',
    'Open Task' => 'Åpen oppgave',
    'Other Tasks' => 'Andre oppgaver',
    'Overdue' => 'På overtid',
    'Overview' => 'Oversikt',
    'Pending' => 'Avventer',
    'Pending Review' => 'Avventer gjennomgang',
    'Ready For Review' => 'Klar for gjennomgang',
    'Reject Task' => 'Avslå oppgave',
    'Request extension' => 'Be om forlengelse',
    'Request sent' => 'Forespørsel sendt',
    'Reset Task' => 'Tilbakestill oppgave',
    'Responsible' => 'Ansvarlig',
    'Scheduling' => 'Planlegging',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Vis {count} mer ferdidge {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Sorteringsrekkefølge',
    'Sort order' => 'Sorteringsrekkefølge',
    'Spaces' => 'Grupper',
    'Start Date' => 'Starter dato',
    'Start Time' => 'Start',
    'Status' => 'Status',
    'Task' => 'Oppgave',
    'Task Users have been notified' => 'Oppgave bruker er blitt varslet',
    'Tasks' => 'Oppgaver',
    'Tasks: Reminder' => 'Oppgaver: Påminnelser',
    'This task can only be processed by assigned and responsible users.' => 'Denne oppgaven kan kun bli håndtert av brukeren som har fått den tildelt og er ansvarlig.',
    'This task requires to be reviewed by a responsible' => 'Denne oppgaven må gjennomgås av den ansvarlige for oppgaven.',
    'Time Zone' => 'Tidssone',
    'Title' => 'Tittel',
    'Today' => 'I dag',
    'Unsorted' => 'Usortert',
    'View Online' => 'Se online',
    'You are assigned!' => 'Du er tildelt.',
    'You are responsible!' => 'Du er ansvarlig',
    'You have insufficient permissions to perform that operation!' => 'Du har ikke tilgang til å utføre handlingen!',
    'Your Reminder for task {task}' => 'Din påminnelse for oppgaven {task}',
    'ending Review' => 'Avslutt gjennomgang',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# dag} other{# dager}} gjenstår',
    '{displayName} is assigned to this task' => '{displayName} er tildelt til denne oppgaven',
    '{displayName} is responsible for this task' => '{displayName} er ansvarlig for denne oppgaven',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} tildelte deg som ansvarlig for oppgaven {task} for gruppen {spaceName}.',
    '{userName} completed task {task}.' => '{userName} har fulført oppgaven {task}.',
    '{userName} finished task {task}.' => '{userName} fullførte oppgave {task}.',
    '{userName} reset task {task}.' => '{userName} har tilbakestilt oppgaven {task}.',
    '{userName} reviewed task {task}.' => '{userName} gjennomgår oppgaven {task}.',
    '{userName} works on task {task}.' => '{userName} arbeider med oppgaven {task}.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checklist Items' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline: ' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No results found for the given filter.' => '',
    'Parent Task' => '',
    'Process unassigned tasks' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Start' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'view all' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Tildelte brukere</strong> kan utføre denne oppgaven',
    '<strong>Create</strong> task list' => '<strong>Lag</strong> liste av oppgaver',
    '<strong>Edit</strong> task' => '<strong>Rediger</strong> oppgave',
    '<strong>Edit</strong> task list' => '<strong>Rediger</strong> listen med oppgaver',
    '<strong>Your</strong> tasks' => '<strong>Dine</strong> oppgaver',
    'Accept Task' => 'Godta oppgave',
    'Add task' => 'Legg til oppgave',
    'All Day' => 'Hele dagen',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Tillater brukeren å opprette nye oppgaver, brukeren vil kun kunne redigere og slette egne oppgaver',
    'Already requested' => 'Allerede forespurt',
    'Assign users' => 'Tilknytt brukere',
    'Begin Task' => 'Start oppgaven',
    'Checklist:' => 'Sjekliste:',
    'Close' => 'Lukk',
    'Color' => 'Farge',
    'Completed' => 'Ferdig',
    'Continue Review' => 'Fortsett gjennomgangen',
    'Create tasks' => 'Lag oppgaver',
    'Created by me' => 'Opprettet av meg',
    'Date' => 'Dato',
    'Delete' => 'Slett',
    'Delete list' => 'Slett liste',
    'Description' => 'Beskrivelse',
    'Do you really want to delete this task?' => 'Ønsker du virkelig og slette denne oppgaven?',
    'Edit' => 'Rediger',
    'Edit list' => 'Rediger liste',
    'End' => 'Slutt',
    'End Date' => 'Slutter dato',
    'End Time' => 'Slutt',
    'End time must be after start time!' => 'Aktiviteten kan ikke slutte før den har startet!',
    'Filter' => 'Filter',
    'Finish Task' => 'Avsluttede oppgaver',
    'General' => 'Generelt',
    'General Settings' => 'Generelle innstillinger ',
    'Hide this list once all tasks are completed' => 'Skjul listen når alle oppgavene er ferdige',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Hvis ingen tilordnet bruker er valgt, kan hvert gruppemedlem med tillatelse til å behandle ufordelte oppgaver, behandle oppgaven.',
    'In Progress' => 'I arbeid',
    'In Review' => 'Under gjennomgang',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Hvis vurderingsalternativet er aktivt, må en <strong>ansvarlig</strong> bruker vurdere og avvise eller bekrefte denne oppgaven før ferdigstillelse.',
    'Invalid task list selection.' => 'Ugyldig valg av oppgave liste',
    'Let Task Review' => 'La oppgave gjennomgang',
    'No Scheduling set for this Task' => 'Ingen planlegging satt til denne oppgaven',
    'No pending tasks found' => 'Ingen ventende oppgaver',
    'Open Task' => 'Åpen oppgave',
    'Other Tasks' => 'Andre oppgaver',
    'Overdue' => 'På overtid',
    'Overview' => 'Oversikt',
    'Pending' => 'Avventer',
    'Pending Review' => 'Avventer gjennomgang',
    'Ready For Review' => 'Klar for gjennomgang',
    'Reject Task' => 'Avslå oppgave',
    'Request extension' => 'Be om forlengelse',
    'Request sent' => 'Forespørsel sendt',
    'Reset Task' => 'Tilbakestill oppgave',
    'Responsible' => 'Ansvarlig',
    'Scheduling' => 'Planlegging',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Vis {count} mer ferdidge {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Sorteringsrekkefølge',
    'Sort order' => 'Sorteringsrekkefølge',
    'Spaces' => 'Grupper',
    'Start Date' => 'Starter dato',
    'Start Time' => 'Start',
    'Status' => 'Status',
    'Task' => 'Oppgave',
    'Task Users have been notified' => 'Oppgave bruker er blitt varslet',
    'Tasks' => 'Oppgaver',
    'Tasks: Reminder' => 'Oppgaver: Påminnelser',
    'This task requires to be reviewed by a responsible' => 'Denne oppgaven må gjennomgås av den ansvarlige for oppgaven.',
    'Time Zone' => 'Tidssone',
    'Title' => 'Tittel',
    'Today' => 'I dag',
    'Unsorted' => 'Usortert',
    'View Online' => 'Se online',
    'You have insufficient permissions to perform that operation!' => 'Du har ikke tilgang til å utføre handlingen!',
    'Your Reminder for task {task}' => 'Din påminnelse for oppgaven {task}',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# dag} other{# dager}} gjenstår',
    '{displayName} is assigned to this task' => '{displayName} er tildelt til denne oppgaven',
    '{displayName} is responsible for this task' => '{displayName} er ansvarlig for denne oppgaven',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} tildelte deg som ansvarlig for oppgaven {task} for gruppen {spaceName}.',
    '{userName} completed task {task}.' => '{userName} har fulført oppgaven {task}.',
    '{userName} finished task {task}.' => '{userName} fullførte oppgave {task}.',
    '{userName} reset task {task}.' => '{userName} har tilbakestilt oppgaven {task}.',
    '{userName} reviewed task {task}.' => '{userName} gjennomgår oppgaven {task}.',
    '{userName} works on task {task}.' => '{userName} arbeider med oppgaven {task}.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checklist Items' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'Deadline: ' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No results found for the given filter.' => '',
    'Parent Task' => '',
    'Process unassigned tasks' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request Review' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Start' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'view all' => '',
    '{displayName} is task creator' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
];
